@@ -24,6 +24,12 @@ import aws_cdk.aws_s3
 import aws_cdk.aws_sns
 import aws_cdk.aws_sns_subscriptions
 import aws_cdk.core
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-codepipeline-actions", "1.33.0", __name__[0:-6], "aws-codepipeline-actions@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
